<?php
if (!defined('ABSPATH')) {
    exit;
}
?>
<div class="wrap rateme-dashboard">
    <h1>
        <span class="dashicons dashicons-star-filled"></span> 
        <?php _e('RateMe Dashboard', 'rateme'); ?>
    </h1>
    
    <!-- Quick Stats Cards -->
    <div class="rateme-quick-stats">
        <?php
        global $wpdb;
        $stats = $wpdb->get_row("
            SELECT 
                COUNT(*) as total_ratings,
                AVG(rating) as average_rating,
                COUNT(DISTINCT post_id) as rated_posts,
                COUNT(DISTINCT user_ip) as unique_users
            FROM {$wpdb->prefix}rateme_ratings
        ");
        
        $stats_cards = array(
            array(
                'icon' => 'star-filled',
                'value' => number_format($stats->total_ratings),
                'label' => __('Total Ratings', 'rateme'),
                'color' => '#2271b1'
            ),
            array(
                'icon' => 'chart-bar',
                'value' => number_format($stats->average_rating, 1) . '/5',
                'label' => __('Average Rating', 'rateme'),
                'color' => '#46b450'
            ),
            array(
                'icon' => 'admin-post',
                'value' => number_format($stats->rated_posts),
                'label' => __('Rated Posts', 'rateme'),
                'color' => '#826eb4'
            ),
            array(
                'icon' => 'groups',
                'value' => number_format($stats->unique_users),
                'label' => __('Unique Users', 'rateme'),
                'color' => '#d63638'
            )
        );
        
        foreach ($stats_cards as $card) : ?>
            <div class="quick-stat-card" style="--card-color: <?php echo esc_attr($card['color']); ?>">
                <span class="dashicons dashicons-<?php echo esc_attr($card['icon']); ?>"></span>
                <div class="stat-content">
                    <h3><?php echo esc_html($card['value']); ?></h3>
                    <p><?php echo esc_html($card['label']); ?></p>
                </div>
            </div>
        <?php endforeach; ?>
    </div>

    <!-- Shortcodes Section -->
    <div class="rateme-section rateme-shortcodes">
        <div class="section-header">
            <h2>
                <span class="dashicons dashicons-shortcode"></span>
                <?php _e('Shortcodes', 'rateme'); ?>
            </h2>
        </div>
        <div class="section-content">
            <div class="shortcode-grid">
                <div class="shortcode-card">
                    <div class="shortcode-header">
                        <h3><?php _e('Basic Rating Display', 'rateme'); ?></h3>
                        <div class="shortcode-preview">
                            ★★★★★
                        </div>
                    </div>
                    <div class="shortcode-display">
                        <code>[rateme]</code>
                        <button class="button rateme-copy-btn" data-clipboard="[rateme]">
                            <span class="dashicons dashicons-clipboard"></span>
                            <?php _e('Copy', 'rateme'); ?>
                        </button>
                    </div>
                    <p class="description"><?php _e('Displays ratings for the current post.', 'rateme'); ?></p>
                </div>

                <div class="shortcode-card">
                    <div class="shortcode-header">
                        <h3><?php _e('Custom Post Rating', 'rateme'); ?></h3>
                        <div class="shortcode-preview">
                            ★★★★☆
                        </div>
                    </div>
                    <div class="shortcode-display">
                        <code>[rateme id="123"]</code>
                        <button class="button rateme-copy-btn" data-clipboard='[rateme id="123"]'>
                            <span class="dashicons dashicons-clipboard"></span>
                            <?php _e('Copy', 'rateme'); ?>
                        </button>
                    </div>
                    <p class="description"><?php _e('Displays ratings for a specific post ID.', 'rateme'); ?></p>
                </div>

                <div class="shortcode-card">
                    <div class="shortcode-header">
                        <h3><?php _e('Styled Rating Display', 'rateme'); ?></h3>
                        <div class="shortcode-preview">
                            ♥♥♥♥♡
                        </div>
                    </div>
                    <div class="shortcode-display">
                        <code>[rateme style="hearts" size="large"]</code>
                        <button class="button rateme-copy-btn" data-clipboard='[rateme style="hearts" size="large"]'>
                            <span class="dashicons dashicons-clipboard"></span>
                            <?php _e('Copy', 'rateme'); ?>
                        </button>
                    </div>
                    <p class="description"><?php _e('Customized rating display with different styles and sizes.', 'rateme'); ?></p>
                </div>
            </div>
        </div>
    </div>

    <!-- Recent Ratings Section -->
    <div class="rateme-section rateme-recent">
        <div class="section-header">
            <h2>
                <span class="dashicons dashicons-clock"></span> 
                <?php _e('Recent Ratings', 'rateme'); ?>
            </h2>
        </div>
        <div class="section-content">
            <?php
            $recent_ratings = $wpdb->get_results("
                SELECT r.*, p.post_title, p.post_type
                FROM {$wpdb->prefix}rateme_ratings r
                LEFT JOIN {$wpdb->posts} p ON r.post_id = p.ID
                ORDER BY r.date_created DESC
                LIMIT 10
            ");
            ?>
            <table class="wp-list-table widefat fixed striped">
                <thead>
                    <tr>
                        <th><?php _e('Post', 'rateme'); ?></th>
                        <th><?php _e('Rating', 'rateme'); ?></th>
                        <th><?php _e('IP Address', 'rateme'); ?></th>
                        <th><?php _e('Date', 'rateme'); ?></th>
                        <th><?php _e('Type', 'rateme'); ?></th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($recent_ratings as $rating) : 
                        $post_type_obj = get_post_type_object($rating->post_type);
                        $type_label = $post_type_obj ? $post_type_obj->labels->singular_name : $rating->post_type;
                        ?>
                        <tr>
                            <td>
                                <a href="<?php echo get_permalink($rating->post_id); ?>">
                                    <?php echo esc_html($rating->post_title); ?>
                                </a>
                            </td>
                            <td>
                                <div class="rating-display">
                                    <?php
                                    for ($i = 1; $i <= 5; $i++) {
                                        echo '<span class="star ' . ($i <= $rating->rating ? 'filled' : '') . '">★</span>';
                                    }
                                    ?>
                                </div>
                            </td>
                            <td>
                                <code class="ip-address" title="<?php esc_attr_e('IP Address', 'rateme'); ?>">
                                    <?php echo esc_html($rating->user_ip); ?>
                                </code>
                            </td>
                            <td>
                                <?php echo esc_html(human_time_diff(strtotime($rating->date_created), current_time('timestamp'))); ?> ago
                            </td>
                            <td><?php echo esc_html($type_label); ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- Support Button -->
    <div class="rateme-support">
        <a href="https://buymeacoffee.com/wpbuilderpro" class="coffee-support" target="_blank" title="<?php esc_attr_e('Support the Development', 'rateme'); ?>">
            <span class="coffee-icon">☕</span>
            <?php _e('Buy me a coffee', 'rateme'); ?>
            <span class="coffee-heart">♥</span>
        </a>
    </div>
</div>