<?php
class RateMe_Customizer {
    public function register_customizer_settings($wp_customize) {
        // Add RateMe section
        $wp_customize->add_section('rateme_settings', array(
            'title'    => __('RateMe Settings', 'rateme'),
            'priority' => 120,
        ));

        // Design Settings
        $this->add_design_settings($wp_customize);
        
        // Layout Settings
        $this->add_layout_settings($wp_customize);
        
        // Text Settings
        $this->add_text_settings($wp_customize);
        
        // Functionality Settings
        $this->add_functionality_settings($wp_customize);
    }

    private function add_design_settings($wp_customize) {
        // Container Style
        $wp_customize->add_setting('rateme_container_style', array(
            'default' => 'modern',
            'sanitize_callback' => 'sanitize_text_field',
        ));

        $wp_customize->add_control('rateme_container_style', array(
            'label' => __('Container Style', 'rateme'),
            'section' => 'rateme_settings',
            'type' => 'select',
            'choices' => array(
                'modern' => __('Modern', 'rateme'),
                'classic' => __('Classic', 'rateme'),
                'minimal' => __('Minimal', 'rateme'),
            ),
        ));

        // Star Style
        $wp_customize->add_setting('rateme_star_style', array(
            'default' => 'star',
            'sanitize_callback' => 'sanitize_text_field',
        ));

        $wp_customize->add_control('rateme_star_style', array(
            'label' => __('Rating Icon Style', 'rateme'),
            'section' => 'rateme_settings',
            'type' => 'select',
            'choices' => array(
                'star' => __('Stars ★', 'rateme'),
                'heart' => __('Hearts ♥', 'rateme'),
                'circle' => __('Circles ●', 'rateme'),
            ),
        ));

        // Colors
        $wp_customize->add_setting('rateme_star_color', array(
            'default' => '#ffd700',
            'sanitize_callback' => 'sanitize_hex_color',
        ));

        $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'rateme_star_color', array(
            'label' => __('Star Color', 'rateme'),
            'section' => 'rateme_settings',
        )));

        $wp_customize->add_setting('rateme_star_hover_color', array(
            'default' => '#ffa500',
            'sanitize_callback' => 'sanitize_hex_color',
        ));

        $wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'rateme_star_hover_color', array(
            'label' => __('Star Hover Color', 'rateme'),
            'section' => 'rateme_settings',
        )));

        // Size
        $wp_customize->add_setting('rateme_star_size', array(
            'default' => '24',
            'sanitize_callback' => 'absint',
        ));

        $wp_customize->add_control('rateme_star_size', array(
            'label' => __('Star Size (px)', 'rateme'),
            'section' => 'rateme_settings',
            'type' => 'number',
            'input_attrs' => array(
                'min' => 16,
                'max' => 48,
                'step' => 2,
            ),
        ));
    }

    private function add_layout_settings($wp_customize) {
        // Position
        $wp_customize->add_setting('rateme_position', array(
            'default' => 'after',
            'sanitize_callback' => 'sanitize_text_field',
        ));

        $wp_customize->add_control('rateme_position', array(
            'label' => __('Rating Position', 'rateme'),
            'section' => 'rateme_settings',
            'type' => 'select',
            'choices' => array(
                'before' => __('Before Content', 'rateme'),
                'after' => __('After Content', 'rateme'),
                'custom' => __('Custom Position (use shortcode)', 'rateme'),
            ),
        ));

        // Alignment
        $wp_customize->add_setting('rateme_alignment', array(
            'default' => 'center',
            'sanitize_callback' => 'sanitize_text_field',
        ));

        $wp_customize->add_control('rateme_alignment', array(
            'label' => __('Alignment', 'rateme'),
            'section' => 'rateme_settings',
            'type' => 'select',
            'choices' => array(
                'left' => __('Left', 'rateme'),
                'center' => __('Center', 'rateme'),
                'right' => __('Right', 'rateme'),
            ),
        ));
    }

    private function add_text_settings($wp_customize) {
        // Custom Text
        $wp_customize->add_setting('rateme_text_rate', array(
            'default' => __('Rate this:', 'rateme'),
            'sanitize_callback' => 'sanitize_text_field',
        ));

        $wp_customize->add_control('rateme_text_rate', array(
            'label' => __('Rating Label', 'rateme'),
            'section' => 'rateme_settings',
            'type' => 'text',
        ));

        $wp_customize->add_setting('rateme_text_thanks', array(
            'default' => __('Thank you for rating!', 'rateme'),
            'sanitize_callback' => 'sanitize_text_field',
        ));

        $wp_customize->add_control('rateme_text_thanks', array(
            'label' => __('Thank You Message', 'rateme'),
            'section' => 'rateme_settings',
            'type' => 'text',
        ));

        $wp_customize->add_setting('rateme_text_already_rated', array(
            'default' => __('You have already rated this.', 'rateme'),
            'sanitize_callback' => 'sanitize_text_field',
        ));

        $wp_customize->add_control('rateme_text_already_rated', array(
            'label' => __('Already Rated Message', 'rateme'),
            'section' => 'rateme_settings',
            'type' => 'text',
        ));
    }

    private function add_functionality_settings($wp_customize) {
        // Enable/Disable Rating
        $wp_customize->add_setting('rateme_enabled', array(
            'default' => true,
            'sanitize_callback' => 'rest_sanitize_boolean',
        ));

        $wp_customize->add_control('rateme_enabled', array(
            'label' => __('Enable Ratings', 'rateme'),
            'section' => 'rateme_settings',
            'type' => 'checkbox',
        ));

        // Post Types
        $post_types = get_post_types(array('public' => true), 'objects');
        foreach ($post_types as $post_type) {
            $wp_customize->add_setting('rateme_enable_' . $post_type->name, array(
                'default' => true,
                'sanitize_callback' => 'rest_sanitize_boolean',
            ));

            $wp_customize->add_control('rateme_enable_' . $post_type->name, array(
                'label' => sprintf(__('Enable for %s', 'rateme'), $post_type->label),
                'section' => 'rateme_settings',
                'type' => 'checkbox',
            ));
        }
    }
}