<?php
class RateMe_Loader {
    protected $actions;
    protected $filters;

    public function __construct() {
        $this->actions = array();
        $this->filters = array();

        $this->load_dependencies();
        $this->define_admin_hooks();
        $this->define_public_hooks();
        $this->run(); // Add this line to execute hooks
    }

    private function load_dependencies() {
        require_once RATEME_PLUGIN_DIR . 'admin/class-rateme-admin.php';
        require_once RATEME_PLUGIN_DIR . 'public/class-rateme-public.php';
        require_once RATEME_PLUGIN_DIR . 'includes/class-rateme-rating.php';
        require_once RATEME_PLUGIN_DIR . 'includes/class-rateme-customizer.php';
    }

    private function define_admin_hooks() {
        $plugin_admin = new RateMe_Admin();
        $this->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
        $this->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');
        $this->add_action('admin_menu', $plugin_admin, 'add_menu_page');
        
        // Add customizer settings
        $plugin_customizer = new RateMe_Customizer();
        $this->add_action('customize_register', $plugin_customizer, 'register_customizer_settings');
    }

    private function define_public_hooks() {
        $plugin_public = new RateMe_Public();
        $this->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
        $this->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');
        $this->add_action('wp_ajax_rateme_rate', $plugin_public, 'handle_rating');
        $this->add_action('wp_ajax_nopriv_rateme_rate', $plugin_public, 'handle_rating');
        $this->add_filter('the_content', $plugin_public, 'display_rating');
    }

    public function add_action($hook, $component, $callback, $priority = 10, $accepted_args = 1) {
        $this->actions = $this->add($this->actions, $hook, $component, $callback, $priority, $accepted_args);
    }

    public function add_filter($hook, $component, $callback, $priority = 10, $accepted_args = 1) {
        $this->filters = $this->add($this->filters, $hook, $component, $callback, $priority, $accepted_args);
    }

    private function add($hooks, $hook, $component, $callback, $priority, $accepted_args) {
        $hooks[] = array(
            'hook'          => $hook,
            'component'     => $component,
            'callback'      => $callback,
            'priority'      => $priority,
            'accepted_args' => $accepted_args
        );
        return $hooks;
    }

    public function run() {
        foreach ($this->filters as $hook) {
            add_filter($hook['hook'], array($hook['component'], $hook['callback']), $hook['priority'], $hook['accepted_args']);
        }

        foreach ($this->actions as $hook) {
            add_action($hook['hook'], array($hook['component'], $hook['callback']), $hook['priority'], $hook['accepted_args']);
        }
    }
}