<?php
class RateMe_Rating {
    private static function get_user_identifier() {
        $cookie_name = 'rateme_user';
        $user_cookie = isset($_COOKIE[$cookie_name]) ? $_COOKIE[$cookie_name] : '';
        
        if (empty($user_cookie)) {
            $user_cookie = md5(uniqid('rateme_', true));
            if (!headers_sent()) {
                setcookie($cookie_name, $user_cookie, time() + (10 * 365 * 24 * 60 * 60), COOKIEPATH, COOKIE_DOMAIN);
            }
            $_COOKIE[$cookie_name] = $user_cookie; // Set cookie in $_COOKIE array for immediate use
        }
        
        return array(
            'ip' => $_SERVER['REMOTE_ADDR'],
            'cookie' => $user_cookie
        );
    }

    // Rest of the methods remain the same
    public static function can_rate($post_id) {
        global $wpdb;
        $user = self::get_user_identifier();
        
        $exists = $wpdb->get_var($wpdb->prepare(
            "SELECT COUNT(*) FROM {$wpdb->prefix}rateme_ratings 
            WHERE post_id = %d AND (user_ip = %s OR user_cookie = %s)",
            $post_id, $user['ip'], $user['cookie']
        ));
        
        return $exists == 0;
    }

    public static function add_rating($post_id, $rating) {
        if (!self::can_rate($post_id)) {
            return false;
        }

        global $wpdb;
        $user = self::get_user_identifier();
        
        return $wpdb->insert(
            $wpdb->prefix . 'rateme_ratings',
            array(
                'post_id' => $post_id,
                'rating' => $rating,
                'user_ip' => $user['ip'],
                'user_cookie' => $user['cookie']
            ),
            array('%d', '%d', '%s', '%s')
        );
    }

    public static function get_rating_stats($post_id) {
        global $wpdb;
        
        $stats = $wpdb->get_row($wpdb->prepare(
            "SELECT COUNT(*) as count, AVG(rating) as average 
            FROM {$wpdb->prefix}rateme_ratings 
            WHERE post_id = %d",
            $post_id
        ));
        
        return array(
            'count' => (int) $stats->count,
            'average' => round($stats->average, 1)
        );
    }
}