<?php
class RateMe_Public {
    public function enqueue_styles() {
        wp_enqueue_style('rateme-public', RATEME_PLUGIN_URL . 'public/css/rateme-public.css', array(), RATEME_VERSION, 'all');
        
        // Add dynamic styles
        $star_color = get_theme_mod('rateme_star_color', '#ffd700');
        $custom_css = "
            .rateme-stars { color: {$star_color}; }
            .rateme-stars .star:hover,
            .rateme-stars .star.active { color: " . $this->adjust_brightness($star_color, -20) . "; }
        ";
        wp_add_inline_style('rateme-public', $custom_css);
    }

    private function adjust_brightness($hex, $steps) {
        $hex = str_replace('#', '', $hex);
        $r = hexdec(substr($hex, 0, 2));
        $g = hexdec(substr($hex, 2, 2));
        $b = hexdec(substr($hex, 4, 2));

        $r = max(0, min(255, $r + $steps));
        $g = max(0, min(255, $g + $steps));
        $b = max(0, min(255, $b + $steps));

        return sprintf("#%02x%02x%02x", $r, $g, $b);
    }

    public function enqueue_scripts() {
        wp_enqueue_script('rateme-public', RATEME_PLUGIN_URL . 'public/js/rateme-public.js', array('jquery'), RATEME_VERSION, true);
        wp_localize_script('rateme-public', 'ratemeAjax', array(
            'ajax_url' => admin_url('admin-ajax.php'),
            'nonce' => wp_create_nonce('rateme-nonce')
        ));
    }

    public function handle_rating() {
        check_ajax_referer('rateme-nonce', 'nonce');
        
        $post_id = intval($_POST['post_id']);
        $rating = intval($_POST['rating']);
        
        if ($rating < 1 || $rating > 5) {
            wp_send_json_error('Invalid rating value');
        }
        
        if (RateMe_Rating::add_rating($post_id, $rating)) {
            $stats = RateMe_Rating::get_rating_stats($post_id);
            wp_send_json_success($stats);
        } else {
            wp_send_json_error('You have already rated this post');
        }
    }

    public function display_rating($content) {
        // Check if ratings are enabled globally
        if (!get_theme_mod('rateme_enabled', true)) {
            return $content;
        }

        // Check if ratings are enabled for this post type
        $post_type = get_post_type();
        if (!get_theme_mod('rateme_enable_' . $post_type, true)) {
            return $content;
        }

        if (is_singular() && in_the_loop() && is_main_query()) {
            $post_id = get_the_ID();
            $stats = RateMe_Rating::get_rating_stats($post_id);
            $can_rate = RateMe_Rating::can_rate($post_id);
            
            ob_start();
            include RATEME_PLUGIN_DIR . 'public/partials/rating-display.php';
            $rating_html = ob_get_clean();
            
            // Check position setting
            $position = get_theme_mod('rateme_position', 'after');
            return $position === 'before' ? $rating_html . $content : $content . $rating_html;
        }
        return $content;
    }
}