jQuery(document).ready(function($) {
    $('.rateme-stars .star').hover(
        function() {
            var rating = $(this).data('rating');
            highlightStars(rating);
        },
        function() {
            var container = $(this).closest('.rateme-container');
            var currentRating = container.data('current-rating');
            highlightStars(currentRating);
        }
    );

    $('.rateme-stars .star').click(function() {
        if ($(this).closest('.rateme-container').hasClass('rated')) {
            return;
        }

        var rating = $(this).data('rating');
        var postId = $(this).closest('.rateme-container').data('post-id');
        submitRating(postId, rating);
    });

    function highlightStars(rating) {
        $('.rateme-stars .star').each(function() {
            if ($(this).data('rating') <= rating) {
                $(this).addClass('active');
            } else {
                $(this).removeClass('active');
            }
        });
    }

    function submitRating(postId, rating) {
        $.ajax({
            url: ratemeAjax.ajax_url,
            type: 'POST',
            data: {
                action: 'rateme_rate',
                nonce: ratemeAjax.nonce,
                post_id: postId,
                rating: rating
            },
            success: function(response) {
                if (response.success) {
                    updateRatingDisplay(postId, response.data);
                    showMessage('Thank you for rating!', 'success');
                } else {
                    showMessage(response.data, 'error');
                }
            },
            error: function() {
                showMessage('An error occurred. Please try again.', 'error');
            }
        });
    }

    function updateRatingDisplay(postId, stats) {
        var container = $('.rateme-container[data-post-id="' + postId + '"]');
        container.addClass('rated');
        container.data('current-rating', stats.average);
        container.find('.average-rating').text(stats.average);
        container.find('.rating-count').text(stats.count);
        highlightStars(stats.average);
    }

    function showMessage(message, type) {
        var messageDiv = $('<div class="rateme-message ' + type + '">' + message + '</div>');
        $('.rateme-container .rateme-message').remove();
        $('.rateme-container').append(messageDiv);
        setTimeout(function() {
            messageDiv.fadeOut(function() {
                $(this).remove();
            });
        }, 3000);
    }
});