<?php
/**
 * @var int $post_id
 * @var array $stats
 * @var bool $can_rate
 */

$container_style = get_theme_mod('rateme_container_style', 'modern');
$star_style = get_theme_mod('rateme_star_style', 'star');
$alignment = get_theme_mod('rateme_alignment', 'center');
$rate_text = get_theme_mod('rateme_text_rate', __('Rate this:', 'rateme'));
$already_rated_text = get_theme_mod('rateme_text_already_rated', __('You have already rated this.', 'rateme'));

$icons = array(
    'star' => '★',
    'heart' => '♥',
    'circle' => '●'
);
$icon = isset($icons[$star_style]) ? $icons[$star_style] : $icons['star'];

// Generate custom CSS variables
$star_color = get_theme_mod('rateme_star_color', '#ffd700');
$star_hover_color = get_theme_mod('rateme_star_hover_color', '#ffa500');
$star_size = get_theme_mod('rateme_star_size', '24');
?>

<div class="rateme-container style-<?php echo esc_attr($container_style); ?><?php echo !$can_rate ? ' rated' : ''; ?>" 
     data-post-id="<?php echo esc_attr($post_id); ?>"
     data-current-rating="<?php echo esc_attr($stats['average']); ?>"
     style="--rateme-alignment: <?php echo esc_attr($alignment); ?>;
            --rateme-star-color: <?php echo esc_attr($star_color); ?>;
            --rateme-star-hover-color: <?php echo esc_attr($star_hover_color); ?>;
            --rateme-star-size: <?php echo esc_attr($star_size); ?>px;">
    
    <div class="rateme-label"><?php echo esc_html($rate_text); ?></div>
    
    <div class="rateme-stars">
        <?php for ($i = 1; $i <= 5; $i++) : ?>
            <span class="star <?php echo ($i <= $stats['average']) ? 'active' : ''; ?>" 
                  data-rating="<?php echo $i; ?>"><?php echo $icon; ?></span>
        <?php endfor; ?>
    </div>
    
    <div class="rateme-stats">
        <?php printf(
            __('Average rating: %1$s/5 based on %2$s ratings', 'rateme'),
            '<span class="average-rating">' . esc_html($stats['average']) . '</span>',
            '<span class="rating-count">' . esc_html($stats['count']) . '</span>'
        ); ?>
    </div>
    
    <?php if (!$can_rate) : ?>
        <div class="rateme-message info"><?php echo esc_html($already_rated_text); ?></div>
    <?php endif; ?>
</div>