<?php
/**
 * Plugin Name: RateMe
 * Plugin URI: https://monir.website/rateme
 * Description: A powerful and flexible rating system for posts and custom post types with IP/cookie-based protection against duplicate ratings.
 * Version: 1.0.0
 * Requires at least: 5.2
 * Requires PHP: 7.2
 * Author: Monir
 * Author URI: https://monir.website
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: rateme
 * Domain Path: /languages
 */

if (!defined('ABSPATH')) {
    exit;
}

define('RATEME_VERSION', '1.0.0');
define('RATEME_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('RATEME_PLUGIN_URL', plugin_dir_url(__FILE__));

require_once RATEME_PLUGIN_DIR . 'includes/class-rateme-loader.php';
require_once RATEME_PLUGIN_DIR . 'includes/class-rateme-activator.php';
require_once RATEME_PLUGIN_DIR . 'includes/class-rateme-deactivator.php';

// Register activation and deactivation hooks
register_activation_hook(__FILE__, array('RateMe_Activator', 'activate'));
register_deactivation_hook(__FILE__, array('RateMe_Deactivator', 'deactivate'));

// Add plugin action links
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'rateme_add_action_links');
function rateme_add_action_links($links) {
    $plugin_links = array(
        '<a href="' . admin_url('admin.php?page=rateme-settings') . '">' . __('Settings', 'rateme') . '</a>',
        '<a href="' . admin_url('admin.php?page=rateme-settings') . '">' . __('View Details', 'rateme') . '</a>'
    );
    return array_merge($plugin_links, $links);
}

// Initialize the plugin
$rateme = new RateMe_Loader();

// Register shortcode
add_shortcode('rateme', 'rateme_shortcode');
function rateme_shortcode($atts) {
    $atts = shortcode_atts(array(
        'id' => get_the_ID(),
    ), $atts, 'rateme');

    $post_id = intval($atts['id']);
    $stats = RateMe_Rating::get_rating_stats($post_id);
    $can_rate = RateMe_Rating::can_rate($post_id);

    ob_start();
    include RATEME_PLUGIN_DIR . 'public/partials/rating-display.php';
    return ob_get_clean();
}